============
Installation
============

At the command line::

    $ pip install kloudbuster

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv kloudbuster
    $ pip install kloudbuster
